<CFSETTING ENABLECFOUTPUTONLY="Yes">
<!------------------------------------------------------------------------------
NAME:
CF_JS_Vision

DESCRIPTION:
A ColdFusion custom tag that allows the user to specify a JavaScript Vision
module that is needed with a Web page. The custom tag will ensure that all 
the proper JavaScript Vision .js files are accessible to the Web page.
(The tag takes the work out of knowing and coding the dependencies amongst 
the .js files.)

ATTRIBUTES:
MODULEPATH	-	If the USE attribute is INCLUDE, then the user must 
				specify the relative path to the JavaScript Vision .js files.
				If the USE attribute is LINK, then the user can specify either 
				the relative path to, or the URL of, the JavaScript Vision
				.js files.

USE			-	Optional. Either INCLUDE, to include (i.e., using CFINCLUDE) 
				the JavaScript Vision .js files in the page, or LINK, to 
				reference the JavaScript Vision .js using the SRC attribute 
				of the HTML SCRIPT tag. If not specified, the default value 
				is LINK.

MODULE		-	Optional. Comma-delimited list of the names of the JavaScript 
				Vision modules that are to be loaded with the Web page. Takes 
				precendence over the individual module names. (Primarily used 
				with manual programming of tag.)

ARRAY,CALENDAR,COOKIE,CHARACTER,
DATETIME,DEBUG,DIALOG,FIELD,FORM,
HTML,LIST,NUMERIC,STRING,UTILITY
FRAMEMGMT,IMAGEMGMT,SNIFFER,WINDOWMGMT
			-	Set each module name to "Yes" that are to be loaded with the 
				Web page. (Primarily used with entering tag with tag editor.)

NOTES:
n/a

USAGE:
<CF_JS_VISION USE="" 
              MODULEPATH=""
			  ARRAY="" ...>

	or

<CFMODULE TEMPLATE="JS_VISION.cfm"
		  USE=""
		  MODULEPATH=""
		  MODULE="">

MODIFICATIONS:
09/11/1999	-	Initial release
09/19/1999	-	Addition of 'debug' module
12/23/1999	-	Change to allow comma-delimited list in the MODULE attribute
				rather than a single module name.
01/01/2000	-	Adds ability to set each module as an attribute to "Yes" if the
				module is to be loaded with the Web page.
01/11/2000	-	Minor modification to attribute recognition code.
03/20/2000	-	Added code for JS_Vision_WindowMgmt2.js
04/15/2000	-	Modified code for JSV 2.8 usage
10/08/2000	-	Modified code for JSV 2.8.5 usage (Added FORM, ARRAY and MATH)
12/17/2000	-	Modified code for JSV 2.9 usage (Added IMAGEMGMT, FRAMEMGMT and SNIFFER)

AUTHOR:
Gary Krajci (gary.s.krajci@bigfoot.com)
------------------------------------------------------------------------------->

<CFPARAM NAME="ATTRIBUTES.USE" DEFAULT="LINK">
<CFPARAM NAME="ATTRIBUTES.MODULEPATH" DEFAULT="">

<CFSET GlobalsLoaded_ = FALSE>
<CFSET ArrayLoaded_ = FALSE>
<CFSET CalendarLoaded_ = FALSE>
<CFSET CookieLoaded_ = FALSE>
<CFSET CharacterLoaded_ = FALSE>
<CFSET DateTimeLoaded_ = FALSE>
<CFSET DialogLoaded_ = FALSE>
<CFSET FieldLoaded_ = FALSE>
<CFSET FormLoaded_ = FALSE>
<CFSET HTMLLoaded_ = FALSE>
<CFSET ListLoaded_ = FALSE>
<CFSET LinkListLoaded_ = FALSE>
<CFSET MathLoaded_ = FALSE>
<CFSET NumericLoaded_ = FALSE>
<CFSET StringLoaded_ = FALSE>
<CFSET UtilityLoaded_ = FALSE>

<CFSET ImageLoaded_ = FALSE>
<CFSET FrameLoaded_ = FALSE>
<CFSET SnifferLoaded_ = FALSE>
<CFSET WindowLoaded_ = FALSE>

<CFIF IsDefined("ATTRIBUTES.MODULE")>
	<CFSET Module_Names_ = LCase(ATTRIBUTES.MODULE)>
<CFELSE>
	<CFSET Module_Names_ = "">
	<CFSET JSV_Modules_ = "ALL,ARRAY,CALENDAR,COOKIE,CHARACTER,DATETIME,DEBUG,DIALOG,FIELD,FORM,HTML,LIST,NUMERIC,STRING,STRING4,UTILITY,IMAGEMGMT,FRAMEMGMT,SNIFFER,WINDOWMGMT">
	<CFLOOP INDEX="ModuleIndex_" LIST="#JSV_Modules_#" DELIMITERS=",">
		<CFIF IsDefined("ATTRIBUTES.#ModuleIndex_#")>
			<CFIF YesNoFormat(Evaluate("ATTRIBUTES." & ModuleIndex_))>
				<CFSET Module_Names_ = ListAppend(Module_Names_, ModuleIndex_, ",")>
			</CFIF>
		</CFIF>
	</CFLOOP>
</CFIF>

<CFIF ListLen(Module_Names_) NEQ 0>
	<CFLOOP INDEX="ModuleName_" LIST="#Module_Names_#" DELIMITERS=",">
		<CFIF LCase(ATTRIBUTES.USE) IS "link">
			<CFOUTPUT>
			<!--- Globals ----------------------------------------------------->
			<CFIF NOT GlobalsLoaded_>
				<CFSET GlobalsLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Globals.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Array ------------------------------------------------------->
			<CFIF ListFindNoCase("array,all", ModuleName_, ",") NEQ 0 AND NOT ArrayLoaded_>
				<CFSET ArrayLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Array.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Cookie ------------------------------------------------------>
			<CFIF ListFindNoCase("cookie,all", ModuleName_, ",") NEQ 0 AND NOT CookieLoaded_>
				<CFSET CookieLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Cookie.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Calendar ---------------------------------------------------->
			<CFIF ListFindNoCase("calendar,all", ModuleName_, ",") NEQ 0 AND NOT CalendarLoaded_>
				<CFSET CalendarLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Calendar.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Character --------------------------------------------------->
			<CFIF ListFindNoCase("character,datetime,field,form,all", ModuleName_, ",") NEQ 0 AND NOT CharacterLoaded_>
				<CFSET CharacterLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Character.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Math ------------------------------------------------------->
			<CFIF ListFindNoCase("math,all", ModuleName_, ",") NEQ 0 AND NOT MathLoaded_>
				<CFSET MathLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Math.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- String, String4 --------------------------------------------->
			<CFIF ListFindNoCase("string,string4,numeric,field,form,datetime,list,html,utility,windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT StringLoaded_>
				<CFSET StringLoaded_ = TRUE>
				<CFSET String4Loaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_String.js" TYPE="text/javascript"></SCRIPT>
<SCRIPT LANGUAGE="JavaScript1.2" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_String4.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Date/Time --------------------------------------------------->
			<CFIF ListFindNoCase("datetime,field,calendar,all", ModuleName_, ",") NEQ 0 AND NOT DateTimeLoaded_>
				<CFSET DateTimeLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_DateTime.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Dialog ------------------------------------------------------>
			<CFIF ListFindNoCase("dialog,all", ModuleName_, ",") NEQ 0 AND NOT DialogLoaded_>
				<CFSET DialogLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Dialog.js" TYPE="text/javascript"></SCRIPT>
<SCRIPT LANGUAGE="VBScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Dialog.vbs" TYPE="text/vbscript"></SCRIPT>
			</CFIF>
			<!--- Field ------------------------------------------------------->
			<CFIF ListFindNoCase("field,all", ModuleName_, ",") NEQ 0 AND NOT FieldLoaded_>
				<CFSET FieldLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript1.2" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Field.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Form -------------------------------------------------------->
			<CFIF ListFindNoCase("form,all", ModuleName_, ",") NEQ 0 AND NOT FormLoaded_>
				<CFSET FormLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Form.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- HTML -------------------------------------------------------->
			<CFIF ListFindNoCase("html,windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT HTMLLoaded_>
				<CFSET HTMLLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_HTML.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Image Management -------------------------------------------->
			<CFIF ListFindNoCase("imagemgmt,all", ModuleName_, ",") NEQ 0 AND NOT ImageLoaded_>
				<CFSET ImageLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_ImageMgmt.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Link List --------------------------------------------------->
			<CFIF ListFindNoCase("linklist,all", ModuleName_, ",") NEQ 0 AND NOT LinkListLoaded_>
				<CFSET LinkListLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_LinkList.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- List -------------------------------------------------------->
			<CFIF ListFindNoCase("list,string4,all", ModuleName_, ",") NEQ 0 AND NOT ListLoaded_>
				<CFSET ListLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_List.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Numeric ----------------------------------------------------->
			<CFIF ListFindNoCase("numeric,datetime,field,windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT NumericLoaded_>
				<CFSET NumericLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Numeric.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Browser Sniffer --------------------------------------------->
			<CFIF ListFindNoCase("sniffer,all", ModuleName_, ",") NEQ 0 AND NOT SnifferLoaded_>
				<CFSET SnifferLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_BrowserSniffer.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Utility ----------------------------------------------------->
			<CFIF ListFindNoCase("utility,all", ModuleName_, ",") NEQ 0 AND NOT UtilityLoaded_>
				<CFSET UtilityLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_Utility.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Frame Management -------------------------------------------->
			<CFIF ListFindNoCase("framemgmt,all", ModuleName_, ",") NEQ 0 AND NOT FrameLoaded_>
				<CFSET FrameLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_FrameMgmt1.js" TYPE="text/javascript"></SCRIPT>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_FrameMgmt2.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			<!--- Window Management/Debug ------------------------------------->
			<CFIF ListFindNoCase("windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT WindowLoaded_>
				<CFSET WindowLoaded_ = TRUE>
<SCRIPT LANGUAGE="JavaScript" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_WindowMgmt.js" TYPE="text/javascript"></SCRIPT>
<SCRIPT LANGUAGE="JavaScript1.2" SRC="#ATTRIBUTES.MODULEPATH#JS_Vision_WindowMgmt2.js" TYPE="text/javascript"></SCRIPT>
			</CFIF>
			</CFOUTPUT>
		<CFELSE>
			<!--- Globals ----------------------------------------------------->
			<CFIF NOT GlobalsLoaded_>
				<CFSET GlobalsLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Globals.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Array ---------------------------------------------------->
			<CFIF ListFindNoCase("array,all", ModuleName_, ",") NEQ 0 AND NOT ArrayLoaded_>
				<CFSET ArrayLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Array.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Cookie ------------------------------------------------------>
			<CFIF ListFindNoCase("cookie,all", ModuleName_, ",") NEQ 0 AND NOT CookieLoaded_>
				<CFSET CookieLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Cookie.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Calendar ---------------------------------------------------->
			<CFIF ListFindNoCase("calendar,all", ModuleName_, ",") NEQ 0 AND NOT CalendarLoaded_>
				<CFSET CalendarLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Calendar.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Character --------------------------------------------------->
			<CFIF ListFindNoCase("character,datetime,field,form,all", ModuleName_, ",") NEQ 0 AND NOT CharacterLoaded_>
				<CFSET CharacterLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Character.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Math ---------------------------------------------------->
			<CFIF ListFindNoCase("math,all", ModuleName_, ",") NEQ 0 AND NOT MathLoaded_>
				<CFSET MathLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Math.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- String, String4 --------------------------------------------->
			<CFIF ListFindNoCase("string,string4,numeric,field,form,datetime,list,html,utility,windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT StringLoaded_>
				<CFSET StringLoaded_ = TRUE>
				<CFSET String4Loaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_String.js">
</SCRIPT>
<SCRIPT LANGUAGE="JavaScript1.2" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_String4.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Date/Time --------------------------------------------------->
			<CFIF ListFindNoCase("datetime,field,calendar,all", ModuleName_, ",") NEQ 0 AND NOT DateTimeLoaded_>
				<CFSET DateTimeLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_DateTime.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Dialog ------------------------------------------------------>
			<CFIF ListFindNoCase("dialog,all", ModuleName_, ",") NEQ 0 AND NOT DialogLoaded_>
				<CFSET DialogLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Dialog.js">
</SCRIPT>
<SCRIPT LANGUAGE="VBScript" TYPE="text/vbscript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Dialog.vbs">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Field ------------------------------------------------------->
			<CFIF ListFindNoCase("field,all", ModuleName_, ",") NEQ 0 AND NOT FieldLoaded_>
				<CFSET FieldLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript1.2" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Field.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Form -------------------------------------------------------->
			<CFIF ListFindNoCase("form,all", ModuleName_, ",") NEQ 0 AND NOT FormLoaded_>
				<CFSET FormLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Form.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- HTML -------------------------------------------------------->
			<CFIF ListFindNoCase("html,windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT HTMLLoaded_>
				<CFSET HTMLLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_HTML.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Image Management -------------------------------------------->
			<CFIF ListFindNoCase("imagemgmt,all", ModuleName_, ",") NEQ 0 AND NOT ImageLoaded_>
				<CFSET ImageLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_ImageMgmt.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Link List --------------------------------------------------->
			<CFIF ListFindNoCase("linklist,all", ModuleName_, ",") NEQ 0 AND NOT LinkListLoaded_>
				<CFSET LinkListLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_LinkList.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- List -------------------------------------------------------->
			<CFIF ListFindNoCase("list,string4,all", ModuleName_, ",") NEQ 0 AND NOT ListLoaded_>
				<CFSET ListLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_List.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Numeric ----------------------------------------------------->
			<CFIF ListFindNoCase("numeric,datetime,field,windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT NumericLoaded_>
				<CFSET NumericLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Numeric.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Browser Sniffer --------------------------------------------->
			<CFIF ListFindNoCase("sniffer,all", ModuleName_, ",") NEQ 0 AND NOT SnifferLoaded_>
				<CFSET SnifferLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_BrowserSniffer.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Utility ----------------------------------------------------->
			<CFIF ListFindNoCase("utility,all", ModuleName_, ",") NEQ 0 AND NOT UtilityLoaded_>
				<CFSET UtilityLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_Utility.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Frame Management -------------------------------------------->
			<CFIF ListFindNoCase("framemgmt,all", ModuleName_, ",") NEQ 0 AND NOT FrameLoaded_>
				<CFSET FrameLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_FrameMgmt1.js">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_FrameMgmt2.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
			<!--- Window Management/Debug ------------------------------------->
			<CFIF ListFindNoCase("windowmgmt,debug,all", ModuleName_, ",") NEQ 0 AND NOT WindowLoaded_>
				<CFSET WindowLoaded_ = TRUE>
				<CFOUTPUT>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_WindowMgmt.js">
</SCRIPT>
<SCRIPT LANGUAGE="JavaScript1.2" TYPE="text/javascript">
<CFINCLUDE TEMPLATE="#ATTRIBUTES.MODULEPATH#JS_Vision_WindowMgmt2.js">
</SCRIPT>
				</CFOUTPUT>
			</CFIF>
		</CFIF>
	</CFLOOP>
</CFIF>
<CFSETTING ENABLECFOUTPUTONLY="No">
