/* -------------------------------------------------------------------------- */
/*                             JAVASCRIPT VISION                              */
/*                              Cookie  Methods                               */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* Author: Gary S. Krajci                                                     */
/* Email: gary.s.krajci@bigfoot.com                                           */
/* Company: Roaring Fork Software                                             */
/* Date: September 27, 2000                                                   */
/* URL: http://www.iwl.net/customers/gkrajci/JSV/                             */
/* Script Type: JavaScript                                                    */
/* -------------------------------------------------------------------------- */
/*
WM_setCookie(), WM_readCookie(), WM_killCookie()
A set of functions that eases the pain of using cookies.

Source: Webmonkey Code Library
http://hotwired.lycos.com/webmonkey/reference/javascript_code_library/wm_ckie_lib/?tw=reference&category=forms_data

Author: Nadav Savio
Author Email: nadav@wired.com

Usage: 

WM_setCookie('name', 'value'[, hours, 'path', 'domain', secure]);
where name, value, and path are strings, and secure is either true or null. 
Only name and value are required.

WM_readCookie('name');
Returns the value associated with name.

WM_getCookieValue('name');
This is a helper function used by WM_readCookie() and WM_killCookie(). 
It extracts a single value based on name, given a cookie of the form 'name=value'.

WM_killCookie('name'[, 'path', 'domain']);
Remember that path and domain must be supplied if they were set with the cookie.

WM_acceptsCookies: boolean value that is set to true or false.
*/

var WM_acceptsCookies = false;
if(document.cookie == '') {
	// Try to set a cookie
	document.cookie = 'WM_acceptsCookies=yes';
	if(document.cookie.indexOf('WM_acceptsCookies=yes') != -1) {
		WM_acceptsCookies = true; 
   }
}
else {
	WM_acceptsCookies = true;
}

function WM_setCookie(name, value, hours, path, domain, secure) {
    if (WM_acceptsCookies) {
		var not_NN2 = (		navigator && 
							navigator.appName && 
							( navigator.appName == 'Netscape' ) && 
							navigator.appVersion  && 
							( parseInt(navigator.appVersion) == 2 )
					  ) ? false : true;

		// NN2 cannot handle Dates, so skip this part
		if( hours && not_NN2 ) { 
			if ( (typeof(hours) == 'string') && Date.parse(hours) ) {
				// already a Date string
				var numHours = hours;
	    	}
			else if ( typeof(hours) == 'number' ) {
				// Calculate date from number of hours
				var numHours = ( new Date( (new Date()).getTime() + hours*3600000 ) ).toGMTString();
	    	}
		}
		// Set the cookie, adding any parameters that were specified
		document.cookie =	name + '=' + escape(value) + 
							( (numHours) ? (';expires=' + numHours) : '' ) + 
							( (path) ? ';path=' + path : '' ) + 
							( (domain) ? ';domain=' + domain : '' ) + 
							( (secure && (secure == true) ) ? '; secure' : ''); 
    }
}

function WM_readCookie(name) {
	if(document.cookie == '') {
		return false; 
    }
	else {
		var theBigCookie = document.cookie;
		var firstChar = theBigCookie.indexOf(name);	// find the start of 'name'
		var NN2Hack = firstChar + name.length;
		if ( (firstChar != -1) && (theBigCookie.charAt(NN2Hack) == '=') ) {
			// If the cookie is found
			firstChar += name.length + 1; // skip 'name' and '='
			// Find the end of the value string (i.e., the next ';').
			var lastChar = theBigCookie.indexOf(';', firstChar);
			if ( lastChar == -1 ) lastChar = theBigCookie.length;
			return unescape( theBigCookie.substring(firstChar, lastChar) );
		}
		else {
			// If there was no cookie of that name, return false.
	    	return false;
		}
	}
}

function WM_killCookie(name, path, domain) {
	// We need the value to kill the cookie
	var theValue = WM_readCookie(name);
	if ( theValue ) {
		// Set an already-expired cookie
		document.cookie =	name + '=' + theValue + 
							'; expires=Fri, 13-Apr-1970 00:00:00 GMT' + 
							( (path) ? ';path=' + path : '' ) + 
							( (domain) ? ';domain=' + domain : '' ); 
	}
}

function JSV_readCookie(name) {
	var cookieValue = WM_readCookie(name);
	return ( (cookieValue == false) ? null : cookieValue );
}

function JSV_setCookie(name, value, hours, path, domain, secure) {
	WM_setCookie(name, value, hours, path, domain, secure);
}

function JSV_killCookie(name, path, domain) {
	WM_killCookie(name, path, domain);
}
