/* -------------------------------------------------------------------------- */
/*                             JAVASCRIPT VISION                              */
/*                             Date/Time Methods                              */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* Author: Gary S. Krajci                                                     */
/* Email: gary.s.krajci@bigfoot.com                                           */
/* Company: Roaring Fork Software                                             */
/* Date: July 23, 2001                                                        */
/* URL: http://www.roaringforksoftware.com/JSV/                               */
/* Script Type: JavaScript                                                    */
/* -------------------------------------------------------------------------- */

Date.prototype.cMonth = _cMonth;
function _cMonth() {
    return JSV_cMonth(this);
}

Date.prototype.formatDate = _formatDate;
function _formatDate(dateMask) {
    return JSV_formatDate(this, dateMask);
}

Date.prototype.dateDiff = _dateDiff;
function _dateDiff(expD, type) {
    return JSV_dateDiff(this, expD, type);
}

Date.prototype.dateCompare = _dateCompare;
function _dateCompare(expD) {
    return JSV_dateCompare(this, expD);
}

String.prototype.convertDateString = _convertDateString;
function _convertDateString(dateFormat) {
    return JSV_convertDateString(this, dateFormat);
}

daysInMonth = new Array(31,28,31,30,31,30,31,31,30,31,30,31);

monthNames = new Array(	"January","February","March","April","May","June",
						"July","August","September","October","November","December");

dayNames = new Array(	"Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday");


function JSV_isLeapYear(year) {
	if ( typeof year == "object" ) year = JSV_getFullYear(year);
	return ( year%4 == 0 && ( year%100 != 0 || year%400 == 0 ) ? true : false );
}

function JSV_cDOW(onDate, abbreviate) {
	var abbreviate = ( (JSV_cDOW.arguments[1] == null) ? false : abbreviate );
	return ( abbreviate ? dayNames[onDate.getDay()].substring(0,3) : dayNames[onDate.getDay()] )
}

function JSV_nthDay(nth, weekday, month, year) {
	var days = daysInMonth[month];
	if ( month == 1 ) days += ( JSV_isLeapYear(year) ? 1 : 0 );
	var calculatedDate = (nth-1)*7 + 1;
	if ( calculatedDate > days ) calculatedDate = days;
	var specifiedDate = JSV_toDate(month, calculatedDate, year);
	calculatedDate = (nth-1)*7 + 1 + (7 + weekday - specifiedDate.getDay())%7;
    return ( (calculatedDate > days) ? 0 : calculatedDate );
}

function JSV_firstDay(weekday, month, year) {
	var firstDay = 1;
	var specifiedDate = JSV_toDate(month, 1, year);
	if (specifiedDate.getDay() > weekday) 
		firstDay = 8 + weekday -specifiedDate.getDay();
	else if (specifiedDate.getDay() < weekday)
		firstDay = weekday - specifiedDate.getDay() + 1;
	else
		firstDay = 1;
	return firstDay;
}

function JSV_lastDay(weekday, month, year) {
	var days = daysInMonth[month];
	if ( month == 1 ) days += ( JSV_isLeapYear(year) ? 1 : 0 );
	var specifiedDate = JSV_toDate(month, days, year);
    return days - (specifiedDate.getDay() - weekday + 7)%7;
}

function JSV_dateDiff(expD1, expD2) {
	var SECOND = 1000;
	var MINUTE = 60 * SECOND;
	var HOUR = MINUTE * 60;
	var DAY = HOUR * 24;
	var WEEK = DAY * 7;

	var dateType = 
		( JSV_dateDiff.arguments[2] == null ? 'D' : JSV_dateDiff.arguments[2] );

	var dateDivisor = DAY;									// days
	if (dateType == 'w') dateDivisor = WEEK;				// weeks
	else if (dateType == 'h') dateDivisor = HOUR;			// hours
	else if (dateType == 'm') dateDivisor = MINUTE;			// minutes
	else if (dateType == 's') dateDivisor = SECOND;			// seconds
	else if (dateType == 'ms') dateDivisor = 1;				// milliseconds

	var adjustedDelta = Math.abs( ( expD1.getTime() - expD2.getTime() )/dateDivisor );
	return (dateType == 'D' ? Math.floor(adjustedDelta) : adjustedDelta);
}

function JSV_cMonth(onDate, abbreviate) {
	if (JSV_cMonth.arguments.length != 2)
		return monthNames[onDate.getMonth()];
	else
		return monthNames[onDate.getMonth()].substring(0,3);
}

function JSV_isMonth(monthValue) {
	var validMonth = false;
	var charMonth = JSV_toString(monthValue);

	if (!JSV_isWhitespace(charMonth)) {
		var Month = ( (charMonth.charAt(0) == "0") ? charMonth.charAt(1) : charMonth );
		if (JSV_isInteger(Month, false)) {
			var intMonth = parseInt( Month ) - 1;
			validMonth = ( ( intMonth >= 0 && intMonth < 12 ) ? true : false );
		}
		else {
			var i = 0,
				monthLength = charMonth.length;
			for (i=0; i<monthNames.length; i++) {
				if (charMonth.toLowerCase() == monthNames[i].toLowerCase().substring(0,monthLength)) {
					validMonth = true;
					break;
				}
			}
		}
	}
	return validMonth;
}

function JSV_isDay(expD, expM, expY) {
	var retval = false;
	if (JSV_isInteger(expM, false) || 
			JSV_isInteger(expY, false) || 
			JSV_isInteger(expD, false) || 
			JSV_isMonth(expM)) {
		var charDay = JSV_toString(expD);
		var charMonth = JSV_toString(expM);
		var	intDay = parseInt( JSV_trimL(charDay, '0') ),
			intMonth = parseInt( JSV_trimL(charMonth, '0') ) - 1,
			lastDayInMonth = 
				( (intMonth != 1) ? daysInMonth[intMonth] : daysInMonth[1] + ( JSV_isLeapYear(expY) ? 1 : 0 ) );

		if (intDay > 0 && intDay <= lastDayInMonth) retval = true;
	}
	return retval;
}

function JSV_tweleveHourClock(elementArray) {
	var i = 0, retval = false;
	for (i=0; i<elementArray.length; i++) {
		if (elementArray[i] == "AM" || elementArray[i] == "PM" ||
				elementArray[i] == "am" || elementArray[i] == "pm" ||
				elementArray[i] == "a" || elementArray[i] == "A" ||
				elementArray[i] == "p" || elementArray[i] == "P") {
			retval = true;
			break;
		}
	}
	return retval;
}

function JSV_timeOfDay(inHrs, inMins, inSecs) {
	if (inHrs >= 0 && inHrs < 12)
		return 0;		// AM
	else if (inHrs > 12 && inHrs <= 24)
		return 1;		// PM
	else if (inHrs == 12 && inMins == 0 && inSecs == 0)
		return 0;		// AM
	else
		return 1;		// PM
}

function JSV_getFullYear() {
	var yearInQuestion = 
			( 
			  typeof JSV_getFullYear.arguments[0] == "object" ? 
			  JSV_getFullYear.arguments[0].getYear() : 
			  parseInt(JSV_getFullYear.arguments[0])
			);
	return ( yearInQuestion < 1000 ? yearInQuestion + 1900 : yearInQuestion );
}

function JSV_formatDate(dateObj, dateMask) {
	if ( JSV_isWhitespace(JSV_formatDate.arguments[1]) ) dateMask = "dd-mmm-yy";

	var	i = 0,
		tmpString = '',
		formattedDate = '',
		theDate = dateObj.getDate(),
		theMonth = dateObj.getMonth(),
		theYear = JSV_getFullYear(dateObj),
		theHours = dateObj.getHours(),
		theMins = dateObj.getMinutes(),
		theSecs = dateObj.getSeconds(),
		theDay = dateObj.getDay(),
		allowedDelimiters = " -/:,",
		allowedMaskChars = "mdyhsapAMP";

	if (!JSV_allowInString(dateMask, allowedDelimiters + allowedMaskChars)) dateMask = "dd-mmm-yy";

	var adjustedHours = theHours;
	if ( (dateMask.toLowerCase().indexOf("a") != -1 || dateMask.toLowerCase().indexOf("p") != -1) && adjustedHours > 12 ) adjustedHours -= 12;

	var formatArray = JSV_parseString(dateMask, allowedDelimiters, true),
		elementsInArray = formatArray.length,
		isMinutes = false;

	for (i=0; i<elementsInArray; i++)  {
        if (formatArray[i] == "yy")
			formattedDate += theYear.toString().substring(2,4);
			
        else if (formatArray[i] == "yyyy")
			formattedDate += theYear.toString();
			
		else if (formatArray[i] == "dddd")
			formattedDate += dayNames[theDay];

		else if (formatArray[i] == "ddd")
			formattedDate += dayNames[theDay].substring(0,3);

		else if (formatArray[i] == "dd") {
			tmpString = JSV_toString(theDate);
			formattedDate += ( ( (tmpString.length == 1) ? "0" : '' ) + tmpString );
		}

		else if (formatArray[i] == "d")
			formattedDate += theDate;

		else if (formatArray[i] == "mmmm")
			formattedDate += monthNames[theMonth];

		else if (formatArray[i] == "mmm")
			formattedDate += monthNames[theMonth].substring(0,3);

		else if (formatArray[i] == "mm" || formatArray[i] == "m") {
			isMinutes = false;

			if (i > 0)
				if (formatArray[i-1] == ":") isMinutes = true;

			if (i < elementsInArray-1)
				if (formatArray[i+1] == ":") isMinutes = true;

			if (isMinutes)
				tmpString = JSV_toString(theMins);
			else
				tmpString = JSV_toString(theMonth+1);

			if (formatArray[i] == "mm")
				formattedDate += ( ( (tmpString.length == 1) ? "0" : '' ) + tmpString );
		}

		else if (formatArray[i] == "hh") {
			tmpString = JSV_toString(adjustedHours);
			formattedDate += ( ( (tmpString.length == 1) ? "0" : '' ) + tmpString );
		}

		else if (formatArray[i] == "h")
			formattedDate += adjustedHours;

		else if (formatArray[i] == "ss") {
			tmpString = '' + theSecs;
			formattedDate += ( ( (tmpString.length == 1) ? "0" : '' ) + tmpString );
		}

		else if (formatArray[i] == "s")
			formattedDate += theSecs;

		else if (formatArray[i] == "A" || formatArray[i] == "P") {
			if (JSV_timeOfDay(theHours, theMins, theSecs) == 0)
				formattedDate += "A";
			else
				formattedDate += "P";
		}
			
		else if (formatArray[i] == "AM" || formatArray[i] == "PM") {
			if (JSV_timeOfDay(theHours, theMins, theSecs) == 0)
				formattedDate += "AM";
			else
				formattedDate += "PM";
		}
				
		else if (formatArray[i] == "a" || formatArray[i] == "p") {
			if (JSV_timeOfDay(theHours, theMins, theSecs) == 0)
				formattedDate += "a";
			else
				formattedDate += "p";
		}

		else if (formatArray[i] == "am" || formatArray[i] == "pm") {
			if (JSV_timeOfDay(theHours, theMins, theSecs) == 0)
				formattedDate += "am";
			else
				formattedDate += "pm";
		}

        else
			formattedDate += formatArray[i];
	}

	return formattedDate;
}

function JSV_toDate(inMonth, inDay, inYear, inHours, inMinutes, inSeconds) {
	var definedDate = new Date(	inYear,
								inMonth,
								inDay,
								(JSV_toDate.arguments[3] != null ? inHours : 0 ),
								(JSV_toDate.arguments[4] != null ? inMinutes : 0 ),
								(JSV_toDate.arguments[5] != null ? inSeconds : 0 ) );
	return definedDate;
}

function JSV_convertDateString(expDS, dateFormat) {
	var dateArray = JSV_parseString(expDS, "/-", false);
	// 0 - GMT milliseconds (+ or -) since zero hours GMT, January 1, 1970
	// 1 - Wed Mar 31 15:58:17 CST 1999
	dateFormat = ( (JSV_convertDateString.arguments[1] == null) ? 0 : dateFormat );
	var convertedDate = 
			JSV_toDate(	parseInt(JSV_trimL(dateArray[0],'0'))-1, 
						parseInt(JSV_trimL(dateArray[1],'0')), 
						dateArray[2]);
	return ( dateFormat != 0 ? convertedDate : convertedDate.getTime() );
}

function JSV_getDocumentLastModified() {
    var dlm = document.lastModified;
	var documentLastModified = "unknown";
	var gmtMilliseconds = Date.parse(dlm);

	if ( gmtMilliseconds != 0 ) {
		var dlmDate = new Date(gmtMilliseconds);
		documentLastModified = dlmDate.formatDate("mm/dd/yyyy hh:mm:ss");
	}
	return documentLastModified;
}

function JSV_dateCompare(expD1, expD2) {
	var pd1 = Date.parse(expD1), pd2 = Date.parse(expD2);
	if ( pd1 > pd2 ) return 1;
	else if ( pd1 < pd2 ) return -1;
	else return 0;
}
