/* -------------------------------------------------------------------------- */
/*                             JAVASCRIPT VISION                              */
/*                               Form  Methods                                */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* Author: Gary S. Krajci                                                     */
/* Email: gary.s.krajci@bigfoot.com                                           */
/* Company: Roaring Fork Software                                             */
/* Date: February 3, 2002                                                     */
/* Script Type: JavaScript                                                    */
/* URL: http://www.roaringforksoftware.com/JSV/                               */
/* -------------------------------------------------------------------------- */

function JSV_formPointer(expFV) {
	var formPointer = null;
	if ( typeof expFV == "string") {
		formPointer = 
				(	
					expFV.indexOf("document.") == 0 ? 
					eval(expFV) : 
					eval("document." + expFV)
				);
	}
	else if ( typeof expFV == "object") {
		formPointer = expFV;
	}
	return formPointer;
}

function JSV_crlfConversion(expV) {
	return expV.replace(/\n/gi, "%0A").replace(/\r/gi, "%0D");
}

//	mailto
//	Doc JavaScript
//	http://webreference.com/js/column70/
function JSV_mailTo(mailTo, mailBody, mailSubject, mailCC, mailBCC) {
	window.location.href = 
		"mailto:" + mailTo + 
	    "?subject=" + ( mailSubject == null || mailSubject.length == 0 ? "[ No Subject ]" : mailSubject ) + 
    	"&body=" + JSV_crlfConversion(mailBody) +
	    ( mailCC == null || mailCC.length == 0 ? "" : "&cc=" + mailCC ) + 
	    ( mailBCC == null || mailBCC.length == 0 ? "" : "&bcc=" + mailBCC ); 
}

function JSV_storeData(formName, numberOfDays, excludeFields) {
	return MH_storeData( formName, 
                         numberOfDays, 
						 ( excludeFields == null ? '' : excludeFields ) );
}

function JSV_retrieveData(formName) {
	return MH_retrieveData(formName);
}

/******************************************************************************
* formsaver.js                                                                *
*                                                                             *
* Copyright 1999 by Mike Hall.                                                *
* Web address: http://www.brainjar.com                                        *
* Last update: February 5, 2000.                                              *
*                                                                             *
* Allows form data to be saved and restored using a single cookie. May be     *
* used by any form. Fields can optionally be excluded on an individual basis. *
*******************************************************************************/

// Determine if the browser can run this script.

var capable;
var name = navigator.appName.toLowerCase();
var vers = parseFloat(navigator.appVersion);

if ((name.indexOf("netscape") >= 0 && vers >= 4) || (name.indexOf("microsoft") >= 0 && vers >= 4))
  capable = true;
else
  capable = false;

// Constants.

var FLDSEP;    // Special characters used as separators in cookie data string.
var IDXSEP;

if (capable) {
	FLDSEP = String.fromCharCode(1);
	IDXSEP = String.fromCharCode(2);
}

//------------------------------------------------------------------------------
// Stores data currently entered on a form as cookies. Always returns true.
//
//   name    - The form name.
//   days    - Number of days to keep the cookies.
//   exclude - A comma-delimited list of field names that should not be
//             stored. Use to exclude sensitive data such as password,
//             credit card numbers, etc.
//------------------------------------------------------------------------------ 

function MH_storeData(name, days, exclude) {
  var f;
  var expdate;
  var list, include;
  var i;
  var fld;
  var data;

  if (!capable) return true;

  // Get the named form, skip processing if not found.

  if (!(f = document.forms[name])) return true;

  // Initialize the data field.
  // Set the expiration date.

  if (days == "") days = 0;
  expdate = new Date();
  expdate.setTime (expdate.getTime() + (86400 * 1000 * days));

  // Build a list of field names for exclusion.

  list = new Array();
  if (exclude != "") {
    i = 0;
    while ((i = exclude.indexOf(",")) >= 1) {
      list[list.length] = exclude.substr(0, i);
      exclude = exclude.substr(i + 1);
    }
    list[list.length] = exclude;
  }

  // Run through the fields and add field name/value pairs to the data string.

  data = FLDSEP;
  for (i = 0; i < f.length; i++) {
    fld = f.elements[i];

    // Is field in exclusion list?

    include = true;
    for (j = 0; j < list.length; j++)
      if (fld.name == list[j])
        include = false;

      if (include) {

      // Checkboxes and radio buttons.

      if ((fld.type == "checkbox" || fld.type == "radio") && fld.checked)
        data += MH_setData(fld.name, fld.value);

      // Selection lists (single).

      if (fld.type == "select-one")
        if (fld.selectedIndex >= 0)
          data += MH_setData(fld.name, fld.options[fld.selectedIndex].value);

      // Selection lists (multiple). Add a unique name/value pair for each selected item.

      if (fld.type == "select-multiple")
        for (j = 0; j < fld.options.length; j++)
          if (fld.options[j].selected)
            data += MH_setData(fld.name + IDXSEP + j, fld.options[j].value);

      // Text fields.

      if (fld.type == "hidden" || fld.type == "password" || fld.type == "text" || fld.type == "textarea")
        data += MH_setData(fld.name, fld.value);
    }
  }

  // Set the cookie.

  MH_deleteCookie(name);
  MH_setCookie(name, data, expdate);

  return true;
}

//------------------------------------------------------------------------------
// Retrieves data from the cookie and sets the values in the corresponding
// form fields. Returns true if data was found, false otherwise.
//
//   name - The form name.
//------------------------------------------------------------------------------

function MH_retrieveData(name) {
  var f;
  var i, j;
  var fld;
  var s;
  var data;

  if (!capable)
    return false;

  // Get the named form, return if not found.

  if (!(f = document.forms[name]))
    return false;

  // Get the cookie for this form.

  data = MH_getCookie(name);
  if (data == "")
    return false;

  // Run through the fields and retrieve the values.

  for (i = 0; i < f.elements.length; i++) {
    fld = f.elements[i];

    // Checkboxes and radio buttons.

    if ((fld.type == "checkbox" || fld.type == "radio") && (s = MH_getData(fld.name, data)) != null && fld.value == s)
      fld.checked = true;

    // Selection lists (single).

    if (fld.type == "select-one" && (s = MH_getData(fld.name, data)) != null)
      for (j = 0; j < fld.options.length; j++)
        if (fld.options[j].value == s)
          fld.options[j].selected = true;

    // Selection lists (multiple).

    if (fld.type == "select-multiple")
      for (j = 0; j < fld.options.length; j++)
        if ((s = MH_getData(fld.name + IDXSEP + j, data)) != null && fld.options[j].value == s)
          fld.options[j].selected = true;

    // Text fields.

    if ((fld.type == "hidden" || fld.type == "password" || fld.type == "text" || fld.type == "textarea") && (s = MH_getData(fld.name, data)) != null)
      fld.value = s;
  }

  return true;
}

/*******************************************************************************
* These functions set and retrieve the field name/value pairs stored in the    *
* cookie.                                                                      *
*******************************************************************************/

//------------------------------------------------------------------------------
// Given a field name and value, creates a name/value string that can be
// appended to the cookie data. A null string is returned if the given value
// is null.
//------------------------------------------------------------------------------

function MH_setData(name, value) {
  if (value != "")
    return name + "=" + value + FLDSEP;
  else
    return "";
}

//------------------------------------------------------------------------------
// Given a field name, this function will extract the matching value found
// in the data string. Null is returned if no match is found.
//------------------------------------------------------------------------------

function MH_getData(name, data) {
  var i, j;
  var s;

  if (data == "") return null;

  s = FLDSEP + name + "=";
  i = data.indexOf(s);
  if (i >= 0) {
    i += s.length;
    j = data.indexOf(FLDSEP, i);
    if (j >= 0)
      return data.substr(i, j - i);
  }

  return null;
}

/******************************************************************************
* These are the basic functions to set, get and delete a cookie.              *
*******************************************************************************/

//------------------------------------------------------------------------------
// Set a cookie given a name, value and expiration date.
//------------------------------------------------------------------------------

function MH_setCookie(name, value, expires) {
  document.cookie = name + "=" + escape(value) + "; expires=" + expires.toGMTString() +  "; path=/";
}

//------------------------------------------------------------------------------
// Returns the value of the named cookie.
//------------------------------------------------------------------------------

function MH_getCookie(name) {
  var search = name + "=";
  offset = document.cookie.indexOf(search);
  if (offset != -1) {
    offset += search.length;
    end = document.cookie.indexOf(";", offset);
    if (end == -1)
      end = document.cookie.length;
    return unescape(document.cookie.substring(offset, end));
  }
  else
    return "";
}

//------------------------------------------------------------------------------
// Delete the named cookie.
//------------------------------------------------------------------------------

function MH_deleteCookie(name) {
	var expdate = new Date();
	expdate.setTime(expdate.getTime() - (86400 * 1000 * 1));
	MH_setCookie(name, "", expdate);
}

//--- End BrainJar by Mike Hall ------------------------------------------------

//==========================================================================//
//	Function:	JSV_searchSelectBox(in_sFormName, textObj, selectObj)
//	Purpose: Acts as a "searchable" input for a given select box.
//	Parameters:
//		textObj 	- The "search" text box.
//		selectObj	- The select box to search against.
//==========================================================================//
function JSV_searchSelectBox(textObj, selectObj) {
	var j = 0;
	var sOptionComp = "";
	var sSearchString = textObj.value.toUpperCase();
	var iSearchTextLength = sSearchString.length;

	for (j=0; j < selectObj.length; j++) {
		sOptionComp = selectObj.options[j].text.substr(0, iSearchTextLength).toUpperCase();

		if ( sSearchString == sOptionComp ) {
			selectObj.selectedIndex = j;
			selectObj.options[j].selected;
			break;
		}
	}
}
