/* -------------------------------------------------------------------------- */
/*                             JAVASCRIPT VISION                              */
/*                            Mathematical Methods                            */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* Author: Gary S. Krajci                                                     */
/* Email: gary.s.krajci@bigfoot.com                                           */
/* Company: Roaring Fork Software                                             */
/* Date: February 6, 2000                                                     */
/* URL: http://www.roaringforksoftware.com/JSV/                               */
/* Script Type: JavaScript                                                    */
/* -------------------------------------------------------------------------- */

function JSV_factorial(expI) {
	return ( expI != 1 ? expI * JSV_factorial(expI-1) : 1 );
}

// --- Geometry ----------------------------------------------------------------

function JSV_circumferenceCircle(r)  {
	return 2.0 * Math.PI * r;
}

function JSV_areaCircle(r)  {
	return (Math.PI * r * r);
}

function JSV_areaSquare(s)  {
	return (s * s);
}

function JSV_areaRect(l, w)  {
	return (l * w);
}

function JSV_areaTriangle(b, h)  {
	return (0.5 * b * h);
}

function JSV_hypotenuse(leg1, leg2)  {
	return Math.sqrt((leg1*leg1) + (leg2*leg2));
}

function JSV_distance(x1, y1, x2, y2)  {
	return Math.sqrt( ((x2-x1)*(x2-x1)) + ((y2-y1)*(y2-y1)) );
}

function _quadraticSolution(s1, s2) {
	first = s1;
	second = s2;
}

function JSV_quadraticFormula(a, b, c)  {
	var qfAnswer = null;
	//  Notes:	(1)	a cannot be 0.
	//			(2)	If the number inside the radical is negative, then the 
	//				answer will be an imaginary number and set to null.
	if (a != 0) {
		var insideRadical = (b * b) - (4 * a * c);
		if (insideRadical >= 0) {
			var partialCalculation = Math.sqrt( insideRadical )/(2*a);
			var qfAnswer = 
					new _quadraticSolution(
							-b + partialCalculation, 
							-b - partialCalculation
						);
		}
	}
	return qfAnswer;
}

function _point(x, y) {
	x = x
	y = y;
}

function JSV_slope(x1, y1, x2, y2)  {
	return (y2-y1)/(x2-x1);
}

function JSV_perpendicular(x11, y11, x12, y12, x21, y21, x22, y22)  {
	return ( (JSV_slope(x11, y11, x12, y12) * JSV_slope(x21, y21, x22, y22)) == -1 );
}

function JSV_parallel(x11, y11, x12, y12, x21, y21, x22, y22)  {
	return ( JSV_slope(x11, y11, x12, y12) = JSV_slope(x21, y21, x22, y22) );
}

function JSV_midPoint(x1, y1, x2, y2)  {
	var midpoint = new _point( (x1 + x2)/2, (y1 + y2)/2 );
	return midpoint;
}

function JSV_volumeRectangle(l, w, h)  {
	return (l * w * h);
}

function JSV_volumeCube(s)  {
	return (s * s * s);
}
