/* -------------------------------------------------------------------------- */
/*                             JAVASCRIPT VISION                              */
/*                         Window Management Methods                          */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* Author: Gary S. Krajci                                                     */
/* Email: gary.s.krajci@bigfoot.com                                           */
/* Company: Roaring Fork Software                                             */
/* Date: January 17, 2001                                                     */
/* URL: http://www.roaringforksoftware.com/JSV/                               */
/* Script Type: JavaScript                                                    */
/* -------------------------------------------------------------------------- */
/* Functions requested by:                                                    */
/*     Won Lee                                                                */
/*     Systems Consultant                                                     */
/*     New Channel Technologies                                               */
/* -------------------------------------------------------------------------- */

function JSV_xyValues(expX, expY) {
	this.x = expX || 0;
	this.y = expY || 0;
}

function JSV_getWindowDeltas() {
	var wHandle = null;
	var wDimensions = new JSV_xyValues();
	var windowDeltas = new JSV_xyValues();
	if (JSV_getWindowDeltas.arguments.length == 2 && typeof JSV_getWindowDeltas.arguments[0] == 'object') {
		wDimensions.x = JSV_getWindowDeltas.arguments[0].x;
		wDimensions.y = JSV_getWindowDeltas.arguments[0].y;
		wHandle = JSV_getWindowDeltas.arguments[1];
	}
	else if (JSV_getWindowDeltas.arguments.length == 3) {
		wDimensions.x = JSV_getWindowDeltas.arguments[0];
		wDimensions.y = JSV_getWindowDeltas.arguments[1];
		wHandle = JSV_getWindowDeltas.arguments[2];
	}

	// Width
	var iWidth = 0;
	if (window.innerWidth) {
		iWidth = wHandle.innerWidth;
	}
	else if (document.body) {
		if (document.body.clientWidth) {
			iWidth = wHandle.document.body.clientWidth;
		}
	}
	windowDeltas.x = wDimensions.x - iWidth;

	// Height
	var iHeight = 0;
	if (window.innerHeight) {
		iHeight = wHandle.innerHeight;
	}
	else if (document.body) {
		if (document.body.clientHeight) {
			iHeight = wHandle.document.body.clientHeight;
		}
	}
	windowDeltas.y = wDimensions.y - iHeight;

	return windowDeltas;
}

function JSV_getWindowDimensions(wHandle, windowDeltas) {
	var innerDimensions = false;
	var wDimensions = new JSV_xyValues();

	// Width
	if (window.outerWidth) {
		wDimensions.x = wHandle.outerWidth;
	}
	else if (window.innerWidth) {
		innerDimensions = true;
		wDimensions.x = wHandle.innerWidth;
	}
	else if (document.body) {
		if (document.body.clientWidth) {
			innerDimensions = true;
			wDimensions.x = wHandle.document.body.clientWidth;
		}
	}

	// Height
	if (window.outerHeight) {
		wDimensions.y = wHandle.outerHeight;
	}
	else if (window.innerWidth) {
		innerDimensions = true;
		wDimensions.y = wHandle.innerWidth;
	}
	else if (document.body) {
		if (document.body.clientHeight) {
			innerDimensions = true;
			wDimensions.y = wHandle.document.body.clientHeight;
		}
	}

	if (innerDimensions) {
		wDimensions.x += windowDeltas.x;
		wDimensions.y += windowDeltas.y;
	}

	return wDimensions;
}

function JSV_windowCenter() {
	var wWidth = 0, wHeight = 0;
	if (JSV_windowCenter.arguments.length == 1 && typeof JSV_windowCenter.arguments[0] == 'object') {
		wWidth = JSV_windowCenter.arguments[0].x;
		wHeight = JSV_windowCenter.arguments[0].y;
	}
	else if (JSV_windowCenter.arguments.length == 2) {
		wWidth = JSV_windowCenter.arguments[0];
		wHeight = JSV_windowCenter.arguments[1];
	}
	var windowXY = new JSV_xyValues();
	if (wWidth < screen.availWidth) windowXY.x = parseInt( (screen.availWidth - wWidth)/2 );
	if (wHeight < screen.availHeight) windowXY.y = parseInt( (screen.availHeight - wHeight)/2 );
	return windowXY;
}
